@@ -70,6 +70,14 @@ WHERE_AM_I_BASIC = _("Performs the basic where am I operation.")
 # with focus as well as its mnemonic.
 WHERE_AM_I_DETAILED = _("Performs the detailed where am I operation.")
 
+# Translators: This is the description of a dedicated command to speak the
+# selected text (if any) in a document.
+WHERE_AM_I_SELECTED_TEXT = _("Speaks the selected text.")
+
+# Translators: This is the description of a dedicated command to speak details
+# about a link, such as the uri and type of link.
+WHERE_AM_I_LINK = _("Speaks link details.")
+
 # Translators: This command will cause the window's status bar contents to be
 # spoken.
 PRESENT_STATUS_BAR = _("Speaks the status bar.")
@@ -84,13 +92,13 @@ SHOW_FIND_GUI = _("Opens the Find dialog.")
 
 # Translators: the Orca "Find" dialog allows a user to search for text in a
 # window and then move focus to that text. For example, they may want to find
-# the "OK" button. This string is used for finding the next occurence of a
+# the "OK" button. This string is used for finding the next occurrence of a
 # string.
 FIND_NEXT = _("Searches for the next instance of a string.")
 
 # Translators: the Orca "Find" dialog allows a user to search for text in a
 # window and then move focus to that text. For example, they may want to find
-# the "OK" button. This string is used for finding the previous occurence of a
+# the "OK" button. This string is used for finding the previous occurrence of a
 # string.
 FIND_PREVIOUS = _("Searches for the previous instance of a string.")
 
@@ -424,6 +432,12 @@ SHOW_APP_PREFERENCES_GUI = \
 TOGGLE_SPOKEN_INDENTATION_AND_JUSTIFICATION = \
     _("Toggles the speaking of indentation and justification.")
 
+# Translators: Orca has a setting through which users can control how a number is
+# spoken. The options are digits ("1 2 3") and words ("one hundred and twenty
+# three"). This string to be translated refers to an Orca command for quickly
+# toggling between the two options.
+CHANGE_NUMBER_STYLE = _("Changes spoken number style.")
+
 # Translators: Orca allows users to cycle through punctuation levels. None,
 # some, most, or all, punctuation will be spoken.
 CYCLE_PUNCTUATION_LEVEL = _("Cycles to the next speaking of punctuation level.")
@@ -520,7 +534,7 @@ CHAT_PREVIOUS_MESSAGE = _("Speak and braille a previous chat room message.")
 
 # Translators: In chat applications, it is often possible to see that a "buddy"
 # is typing currently (e.g. via a keyboard icon or status text). Some users like
-# to have this typing status announced by Orca; others find that announcment
+# to have this typing status announced by Orca; others find that announcement
 # unpleasant. Therefore, it is a setting in Orca. This string to be translated
 # is associated with the command to toggle typing status presentation on or off.
 CHAT_TOGGLE_BUDDY_TYPING = \
@@ -537,7 +551,7 @@ CHAT_TOGGLE_MESSAGE_HISTORIES = \
     _("Toggle whether we provide chat room specific message " \
       "histories.")
 
-# Translators: In chat applcations, Orca automatically presents incoming
+# Translators: In chat applications, Orca automatically presents incoming
 # messages in speech and braille. If a user is in multiple conversations or
 # channels at the same time, it can be confusing to know what room or channel
 # a given message came from just from hearing/reading it. For this reason, Orca
