@@ -107,7 +107,7 @@ formatting = {
             'detailedWhereAmI' : 'pageSummary'
             },
         pyatspi.ROLE_ALERT: {
-            'unfocused': 'expandedEOCs or (labelOrName + unrelatedLabels)'
+            'unfocused': 'labelOrName + roleName + pause + (expandedEOCs or unrelatedLabels)'
             },
         pyatspi.ROLE_ANIMATION: {
             'unfocused': 'labelAndName'
@@ -225,8 +225,8 @@ formatting = {
             },
         pyatspi.ROLE_LIST_ITEM: {
             'focused': 'expandableState',
-            'unfocused': 'label + displayedText + allTextSelection + pause + expandableState + pause + positionInList + pause + childWidget',
-            'basicWhereAmI': 'label + roleName + pause + name + pause + positionInList + pause + expandableState + (nodeLevel or nestingLevel) + pause'
+            'unfocused': '(labelOrName or (displayedText + allTextSelection)) + pause + expandableState + pause + positionInList + pause + listBoxItemWidgets',
+            'basicWhereAmI': 'label + roleName + pause + (name or displayedText) + pause + positionInList + pause + expandableState + (nodeLevel or nestingLevel) + pause'
             },
         pyatspi.ROLE_MATH: {
             'unfocused': 'math',
@@ -294,7 +294,7 @@ formatting = {
             },
         pyatspi.ROLE_PANEL: {
             'focused': 'labelAndName + roleName',
-            'unfocused': '(substring and currentLineText) or (labelAndName + roleName)'
+            'unfocused': '((substring and currentLineText) or labelAndName) + roleName'
             },
         pyatspi.ROLE_PARAGRAPH: {
             'focused': 'labelOrName + readOnly + textRole + currentLineText + allTextSelection',
@@ -309,8 +309,8 @@ formatting = {
             'detailedWhereAmI': 'label + readOnly + textRole + textContentWithAttributes + anyTextSelection + ' + MNEMONIC
             },
         pyatspi.ROLE_PROGRESS_BAR: {
-            'focused': 'percentage',
-            'unfocused': 'labelAndName + percentage'
+            'focused': 'progressBarIndex + progressBarValue',
+            'unfocused': 'progressBarIndex + labelAndName + progressBarValue'
             },
         pyatspi.ROLE_PUSH_BUTTON: {
             'focused': 'expandableState',
@@ -414,8 +414,8 @@ formatting = {
             },
         pyatspi.ROLE_TOGGLE_BUTTON: {
             'focused': 'expandableState or toggleState',
-            'unfocused': 'labelAndName + roleName + (expandableState or toggleState) + availability + ' + MNEMONIC + ' + accelerator',
-            'basicWhereAmI': 'labelAndName + roleName + (expandableState or toggleState)'
+            'unfocused': 'labelOrName + roleName + (expandableState or toggleState) + availability + ' + MNEMONIC + ' + accelerator',
+            'basicWhereAmI': 'labelOrName + roleName + (expandableState or toggleState)'
             },
         pyatspi.ROLE_TOOL_TIP: {
             'unfocused': 'labelAndName',
@@ -566,11 +566,11 @@ formatting = {
                           or ([Component(obj,\
                                      asString(label + displayedText + expandableState + roleName + availability) + asString(accelerator))]\
                           + (nestingLevel and [Region(" " + asString(nestingLevel))])\
-                          + (childWidget and ([Region(" ")] + childWidget))))',
+                          + (listBoxItemWidgets and ([Region(" ")] + listBoxItemWidgets))))',
             'unfocused': '((substring and ' + BRAILLE_TEXT + ')\
                           or ([Component(obj, asString(labelOrName + expandableState))]\
                               + (nestingLevel and [Region(" " + asString(nestingLevel))])\
-                              + (childWidget and ([Region(" ")] + childWidget))))',
+                              + (listBoxItemWidgets and ([Region(" ")] + listBoxItemWidgets))))',
             },
         pyatspi.ROLE_MENU: {
             'focused':   '[Component(obj,\
@@ -606,7 +606,11 @@ formatting = {
         pyatspi.ROLE_PASSWORD_TEXT: {
             'unfocused': BRAILLE_TEXT
             },
-        #pyatspi.ROLE_PROGRESS_BAR: 'default'
+        pyatspi.ROLE_PROGRESS_BAR: {
+            'unfocused': '(progressBarValue and \
+                           [Component(obj, asString(labelAndName + progressBarValue + roleName + progressBarIndex))]) \
+                           or []'
+            },
         pyatspi.ROLE_PUSH_BUTTON: {
             'unfocused': '[Component(obj,\
                                      asString((labelAndName or description) + expandableState + roleName))]'
