@@ -102,6 +102,30 @@ BTN_JUMP_TO = _("_Jump to")
 # Translators: This is the label for a button in a dialog.
 BTN_OK = _("_OK")
 
+# Translators: Orca uses Speech Dispatcher to present content to users via
+# text-to-speech. Speech Dispatcher has a feature to control how capital
+# letters are presented: Do nothing at all, say the word 'capital' prior to
+# presenting a capital letter (which Speech Dispatcher refers to as 'spell'),
+# or play a tone (which Speech Dispatcher refers to as a sound 'icon'.) This
+# string to be translated appears as a combo box item in Orca's Preferences.
+CAPITALIZATION_STYLE_ICON = C_("capitalization style", "icon")
+
+# Translators: Orca uses Speech Dispatcher to present content to users via
+# text-to-speech. Speech Dispatcher has a feature to control how capital
+# letters are presented: Do nothing at all, say the word 'capital' prior to
+# presenting a capital letter (which Speech Dispatcher refers to as 'spell'),
+# or play a tone (which Speech Dispatcher refers to as a sound 'icon'.) This
+# string to be translated appears as a combo box item in Orca's Preferences.
+CAPITALIZATION_STYLE_NONE = C_("capitalization style", "none")
+
+# Translators: Orca uses Speech Dispatcher to present content to users via
+# text-to-speech. Speech Dispatcher has a feature to control how capital
+# letters are presented: Do nothing at all, say the word 'capital' prior to
+# presenting a capital letter (which Speech Dispatcher refers to as 'spell'),
+# or play a tone (which Speech Dispatcher refers to as a sound 'icon'.) This
+# string to be translated appears as a combo box item in Orca's Preferences.
+CAPITALIZATION_STYLE_SPELL = C_("capitalization style", "spell")
+
 # Translators: If this checkbox is checked, then Orca will tell you when one of
 # your buddies is typing a message.
 CHAT_ANNOUNCE_BUDDY_TYPING = _("Announce when your _buddies are typing")
@@ -125,7 +149,7 @@ CHAT_SPEAK_MESSAGES_ALL = _("All cha_nnels")
 
 # Translators: This is the label of a radio button. If it is selected, Orca will
 # speak all new chat messages as they appear if and only if the chat application
-# has focus. The string substituion is for the application name (e.g Pidgin).
+# has focus. The string substitution is for the application name (e.g Pidgin).
 CHAT_SPEAK_MESSAGES_ALL_IF_FOCUSED = _("All channels when an_y %s window is active")
 
 # Translators: This is the label of a radio button. If it is selected, Orca will
@@ -653,7 +677,7 @@ READ_PAGE_UPON_LOAD = \
 # Translators: Different speech systems and speech engines work differently when
 # it comes to handling pauses (e.g. sentence boundaries). This property allows
 # the user to specify whether speech should be sent to the speech synthesis
-# system immediately when a pause directive is enountered or if it should be
+# system immediately when a pause directive is encountered or if it should be
 # queued up and sent to the speech synthesis system once the entire set of
 # utterances has been calculated.
 SPEECH_BREAK_INTO_CHUNKS = _("Break speech into ch_unks between pauses")
