@@ -596,7 +596,7 @@ class Script(default.Script):
         default.Script.locusOfFocusChanged(self, event,
                                            oldLocusOfFocus, newLocusOfFocus)
 
-        if self.utilities.isDocumentCell(newLocusOfFocus):
+        if self.utilities.isTextDocumentCell(newLocusOfFocus):
             row, column, table = \
                 self.utilities.getRowColumnAndTable(newLocusOfFocus.parent)
             self.pointOfReference['lastRow'] = row
@@ -673,7 +673,7 @@ class Script(default.Script):
             return
 
         if anyDataRole == pyatspi.ROLE_TABLE:
-            if self.utilities.isSpreadSheetCell(event.any_data, True):
+            if self.utilities.isSpreadSheetCell(event.any_data):
                 orca.setLocusOfFocus(event, event.any_data)
             return
 
@@ -774,8 +774,7 @@ class Script(default.Script):
 
         if role == pyatspi.ROLE_PARAGRAPH:
             obj, offset = self.pointOfReference.get("lastCursorPosition", (None, -1))
-            textSelections = self.pointOfReference.get('textSelections', {})
-            start, end = textSelections.get(hash(obj), (0, 0))
+            start, end, string = self.utilities.getCachedTextSelection(obj)
             if start != end:
                 return
 
@@ -806,11 +805,11 @@ class Script(default.Script):
 
         if self.utilities.isSpreadSheetCell(orca_state.locusOfFocus):
             msg = "SOFFICE: locusOfFocus %s is spreadsheet cell" % orca_state.locusOfFocus
-            debug.println(debug.LEVEL_INFO, msg)
+            debug.println(debug.LEVEL_INFO, msg, True)
 
             if not self.utilities.isCellBeingEdited(event.source):
                 msg = "SOFFICE: Event ignored: Source is not cell being edited."
-                debug.println(debug.LEVEL_INFO, msg)
+                debug.println(debug.LEVEL_INFO, msg, True)
                 return
 
         super().onCaretMoved(event)
