@@ -77,6 +77,9 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
     def _generateTextRole(self, obj, **args):
         result = []
         role = args.get('role', obj.getRole())
+        if role == pyatspi.ROLE_TEXT and obj.parent.getRole() == pyatspi.ROLE_COMBO_BOX:
+            return []
+
         if role != pyatspi.ROLE_PARAGRAPH \
            or self.__overrideParagraph(obj, **args):
             result.extend(self._generateRoleName(obj, **args))
@@ -109,6 +112,9 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         if nothing can be found.
         """
         role = args.get('role', obj.getRole())
+        if role == pyatspi.ROLE_TEXT and obj.parent.getRole() == pyatspi.ROLE_COMBO_BOX:
+            return []
+
         if role in [pyatspi.ROLE_PUSH_BUTTON, pyatspi.ROLE_TOGGLE_BUTTON] \
            and self._script.utilities.ancestorWithRole(
                 obj, [pyatspi.ROLE_TOOL_BAR], [pyatspi.ROLE_FRAME]):
@@ -123,6 +129,11 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
 
     def _generateLabelOrName(self, obj, **args):
         """Gets the label or the name if the label is not preset."""
+
+        role = args.get('role', obj.getRole())
+        if role == pyatspi.ROLE_TEXT and obj.parent.getRole() == pyatspi.ROLE_COMBO_BOX:
+            return []
+
         result = []
         acss = self.voice(speech_generator.DEFAULT)
         override = self.__overrideParagraph(obj, **args)
@@ -159,7 +170,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         """
 
         result = []
-        if not self._script.utilities.isSpreadSheetCell(obj, startFromTable=True):
+        if not self._script.utilities.isSpreadSheetCell(obj):
             result.extend(speech_generator.SpeechGenerator.\
                 _generateAvailability(self, obj, **args))
 
@@ -174,6 +185,9 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         if _settingsManager.getSetting('onlySpeakDisplayedText'):
             return []
 
+        if not args.get('formatType', '').endswith('WhereAmI'):
+            return []
+
         result = []
         acss = self.voice(speech_generator.SYSTEM)
         if obj.description:
@@ -195,7 +209,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         return result
 
     def _generateCurrentLineText(self, obj, **args):
-        if self._script.utilities.isDocumentCell(obj.parent):
+        if self._script.utilities.isTextDocumentCell(obj.parent):
             priorObj = args.get('priorObj', None)
             if priorObj and priorObj.parent != obj.parent:
                 return []
@@ -204,12 +218,16 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         # together in the scripts. In addition, the voice crap needs to go
         # here. Then it needs to be removed from the scripts.
         [text, caretOffset, startOffset] = self._script.getTextLineAtCaret(obj)
+        voice = self.voice(string=text)
         text = self._script.utilities.adjustForLinks(obj, text, startOffset)
         text = self._script.utilities.adjustForRepeats(text)
         if not text:
-            text = [messages.BLANK]
+            result = [messages.BLANK]
+        else:
+            result = [text]
+        result.extend(voice)
 
-        return [text]
+        return result
 
     def _generateToggleState(self, obj, **args):
         """Treat toggle buttons in the toolbar specially. This is so we can
@@ -237,7 +255,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         row header(s).
         """
 
-        if _settingsManager.getSetting('readTableCellRow'):
+        if self._script.utilities.shouldReadFullRow(obj):
             return []
 
         newOnly = args.get('newOnly', False)
@@ -356,7 +374,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         if speakCoordinates and not isBasicWhereAmI:
             result.append(self._script.utilities.spreadSheetCellName(obj))
 
-        if _settingsManager.getSetting('readTableCellRow'):
+        if self._script.utilities.shouldReadFullRow(obj):
             row, col, table = self._script.utilities.getRowColumnAndTable(obj)
             lastRow = self._script.pointOfReference.get("lastRow")
             if row != lastRow:
@@ -378,7 +396,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         """Get the speech for a table cell row if the user wants to hear
         the full row and if the row has actually changed."""
 
-        speakFullRow = _settingsManager.getSetting('readTableCellRow')
+        speakFullRow = self._script.utilities.shouldReadFullRow(obj)
         if speakFullRow:
             row, column, table = \
                 self._script.utilities.getRowColumnAndTable(obj)
@@ -446,6 +464,12 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         return speech_generator.SpeechGenerator._generateOldAncestors(
             self, obj, **args)
 
+    def _generateUnselectedCell(self, obj, **args):
+        if self._script.utilities.isSpreadSheetCell(obj):
+            return []
+
+        return super()._generateUnselectedCell(obj, **args)
+
     def generateSpeech(self, obj, **args):
         result = []
         if args.get('formatType', 'unfocused') == 'basicWhereAmI' \
