@@ -31,11 +31,16 @@ import orca.orca as orca
 import orca.orca_state as orca_state
 import orca.scripts.default as default
 
+from .script_utilities import Utilities
+
 class Script(default.Script):
 
     def __init__(self, app):
         default.Script.__init__(self, app)
 
+    def getUtilities(self):
+        return Utilities(self)
+
     def onActiveDescendantChanged(self, event):
         """Callback for object:active-descendant-changed accessibility events."""
 
@@ -67,6 +72,11 @@ class Script(default.Script):
             orca.setLocusOfFocus(event, event.source)
             return
 
+        # The above issue also seems to happen with spin buttons.
+        if role == pyatspi.ROLE_SPIN_BUTTON:
+            orca.setLocusOfFocus(event, event.source)
+            return
+
         # https://bugzilla.gnome.org/show_bug.cgi?id=720987
         if role == pyatspi.ROLE_TABLE_COLUMN_HEADER:
             orca.setLocusOfFocus(event, event.source)
@@ -91,8 +101,13 @@ class Script(default.Script):
         # selected, we get a focus: event for that menu item, but there is
         # not a state-changed event for that item, nor a selection-changed
         # event for the menu.
-        if role == pyatspi.ROLE_MENU_ITEM:
-            orca.setLocusOfFocus(event, event.source)
+        menuItems = [pyatspi.ROLE_CHECK_MENU_ITEM,
+                     pyatspi.ROLE_MENU_ITEM,
+                     pyatspi.ROLE_RADIO_MENU_ITEM]
+        if role in menuItems:
+            if orca_state.locusOfFocus \
+               and orca_state.locusOfFocus.parent != event.source.parent:
+                orca.setLocusOfFocus(event, event.source)
             return
 
         # Unfiled, but in at least some dialogs, the first time a push
