@@ -194,11 +194,15 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         if role not in [pyatspi.ROLE_LIST, pyatspi.ROLE_LIST_BOX]:
             return super()._generateNumberOfChildren(obj, **args)
 
-        children = [x for x in obj if x.getRole() == pyatspi.ROLE_LIST_ITEM]
-        if not children:
+        setsize = self._script.utilities.getSetSize(obj[0])
+        if setsize is None:
+            children = [x for x in obj if x.getRole() == pyatspi.ROLE_LIST_ITEM]
+            setsize = len(children)
+
+        if not setsize:
             return []
 
-        result = [messages.listItemCount(len(children))]
+        result = [messages.listItemCount(setsize)]
         result.extend(self.voice(speech_generator.SYSTEM))
         return result
 
@@ -256,6 +260,8 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             if (start or end):
                 doNotSpeak.append(pyatspi.ROLE_DOCUMENT_FRAME)
                 doNotSpeak.append(pyatspi.ROLE_ALERT)
+            if self._script.utilities.isAnchor(obj):
+                doNotSpeak.append(obj.getRole())
 
         if obj.getState().contains(pyatspi.STATE_EDITABLE):
             lastKey, mods = self._script.utilities.lastKeyAndModifiers()
@@ -280,7 +286,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                 result.append(self.getLocalizedRoleName(obj, role))
                 result.extend(acss)
 
-        elif role == pyatspi.ROLE_LINK:
+        elif self._script.utilities.isLink(obj):
             if obj.parent.getRole() == pyatspi.ROLE_IMAGE:
                 result.append(messages.IMAGE_MAP_LINK)
                 result.extend(acss)
@@ -402,13 +408,8 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         if self._script.utilities.isTextBlockElement(obj):
             return []
 
-        try:
-            attrs = dict([attr.split(':', 1) for attr in obj.getAttributes()])
-        except:
-            attrs = {}
-
-        position = attrs.get("posinset")
-        total = attrs.get("setsize")
+        position = self._script.utilities.getPositionInSet(obj)
+        total = self._script.utilities.getSetSize(obj)
         if position is None or total is None:
             return super()._generatePositionInList(obj, **args)
 
@@ -428,18 +429,20 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
 
     def generateSpeech(self, obj, **args):
         if not self._script.utilities.inDocumentContent(obj):
-            msg = "\nINFO: %s is not in document content. Calling default speech generator." % obj
-            debug.println(debug.LEVEL_INFO, msg)
+            msg = "WEB: %s is not in document content. Calling default speech generator." % obj
+            debug.println(debug.LEVEL_INFO, msg, True)
             return super().generateSpeech(obj, **args)
 
-        msg = "\nINFO: Generating speech for document object %s" % obj
-        debug.println(debug.LEVEL_INFO, msg)
+        msg = "WEB: Generating speech for document object %s" % obj
+        debug.println(debug.LEVEL_INFO, msg, True)
 
         result = []
         if args.get('formatType') == 'detailedWhereAmI':
             oldRole = self._overrideRole('default', args)
         elif self._script.utilities.isLink(obj):
             oldRole = self._overrideRole(pyatspi.ROLE_LINK, args)
+        elif self._script.utilities.isAnchor(obj):
+            oldRole = 'ROLE_STATIC'
         elif self._script.utilities.treatAsDiv(obj):
             oldRole = self._overrideRole(pyatspi.ROLE_SECTION, args)
         else:
@@ -449,8 +452,11 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         result = list(filter(lambda x: x, result))
         self._restoreRole(oldRole, args)
 
-        msg = "\nINFO: Speech generation for document object %s complete:\n%s\n" % (obj, result)
+        msg = "WEB: Speech generation for document object %s complete:" % obj
         debug.println(debug.LEVEL_INFO, msg)
+        for element in result:
+            debug.println(debug.LEVEL_ALL, "           %s" % element)
+
         return result
 
     def generateContents(self, contents, **args):
@@ -459,13 +465,13 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
 
         result = []
         contents = self._script.utilities.filterContentsForPresentation(contents, False)
-        msg = "INFO: Generating speech contents (length: %i)" % len(contents)
-        debug.println(debug.LEVEL_INFO, msg)
+        msg = "WEB: Generating speech contents (length: %i)" % len(contents)
+        debug.println(debug.LEVEL_INFO, msg, True)
         for i, content in enumerate(contents):
             obj, start, end, string = content
             msg = "ITEM %i: %s, start: %i, end: %i, string: '%s'" \
                   % (i, obj, start, end, string)
-            debug.println(debug.LEVEL_INFO, msg)
+            debug.println(debug.LEVEL_INFO, msg, True)
             utterance = self.generateSpeech(
                 obj, startOffset=start, endOffset=end, string=string,
                 index=i, total=len(contents), **args)
