@@ -210,6 +210,10 @@ class SpeechGenerator(generator.Generator):
         if _settingsManager.getSetting('onlySpeakDisplayedText'):
             return []
 
+        priorObj = args.get('priorObj')
+        if priorObj and priorObj.getRole() == pyatspi.ROLE_TOOL_TIP:
+            return []
+
         acss = self.voice(SYSTEM)
         result = generator.Generator._generateDescription(self, obj, **args)
         if result:
@@ -1468,8 +1472,10 @@ class SpeechGenerator(generator.Generator):
         if role not in [pyatspi.ROLE_LIST, pyatspi.ROLE_LIST_BOX]:
             return result
 
-        items = self._script.utilities.selectedChildren(obj)
-        items = items or [self._script.utilities.focusedChild(obj)]
+        if 'Selection' in pyatspi.listInterfaces(obj):
+            items = self._script.utilities.selectedChildren(obj)
+        else:
+            items = [self._script.utilities.focusedChild(obj)]
         if not (items and items[0]):
             return result
 
@@ -1566,6 +1572,9 @@ class SpeechGenerator(generator.Generator):
         """
         result = []
         priorObj = args.get('priorObj', None)
+        if priorObj and priorObj.getRole() == pyatspi.ROLE_TOOL_TIP:
+            return []
+
         commonAncestor = self._script.utilities.commonAncestor(priorObj, obj)
         try:
             role = commonAncestor.getRole()
@@ -2319,4 +2328,10 @@ class SpeechGenerator(generator.Generator):
         if not rv or rv.get('established') == False:
             rv = voices.get(voiceType.get(DEFAULT))
 
-        return [acss.ACSS(rv)]
+        voice = acss.ACSS(rv)
+        if key in [None, DEFAULT]:
+            string = args.get('string', '')
+            if string.isupper():
+                voice.update(voices.get(voiceType.get(UPPERCASE)))
+
+        return [voice]
